@@ -1,7 +1,8 @@
 from .users import get_users_dataframe
 from .groups import get_groups_dataframe, get_group_users_dataframe
 from .datasources import get_datasources_dataframe, get_datasource_connections_dataframe
-from .workbooks import get_workbooks_dataframe, get_views_dataframe, get_workbook_connections_dataframe
+from .workbooks import get_workbooks_dataframe, get_views_dataframe, get_workbook_connections_dataframe, \
+    get_embedded_datasources_dataframe
 from .sites import get_sites_dataframe, get_active_site_content_url, get_active_site_name, get_active_site_id
 from .projects import get_projects_dataframe
 from .schedules import get_schedules_dataframe
