@@ -47,3 +47,20 @@ def get_workbook_connections_dataframe(conn, workbook_id):
         return connections_df
     except KeyError:
         raise ContentNotFound('workbook', workbook_id)
+
+
+def get_embedded_datasources_dataframe(conn, workbooks_df, workbook_ids=None):
+    """
+    Creates a Pandas DataFrame of all embedded workbook datasources, or specific workbooks if specified.
+    :param TableauServerConnection conn: the Tableau Server connection
+    :param pd.DataFrame workbooks_df: the workbook DataFrame containing details for all workbooks
+    :param list workbook_ids: a list of workbook IDs whose embedded datasources will be queried
+    :return:
+    """
+    if workbook_ids:
+        workbooks_df = workbooks_df[workbooks_df['id'].isin(workbook_ids)]
+    embedded_datasources_df = pd.DataFrame()
+    for index, workbook in workbooks_df.iterrows():
+        workbook_connections_df = get_workbook_connections_dataframe(conn=conn, workbook_id=workbook['id'])
+        embedded_datasources_df = embedded_datasources_df.append(workbook_connections_df, ignore_index=True, sort=True)
+    return embedded_datasources_df
